==> kubernetes-model-admissionregistration-6.1.1-sources.jar: io/fabric8/kubernetes/api/model/authorization/v1/NonResourceRuleFluent.java <==
package io.fabric8.kubernetes.api.model.authorization.v1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface NonResourceRuleFluent<A extends NonResourceRuleFluent<A>> extends Fluent<A>{
  public A addToNonResourceURLs(Integer index,String item);
  public A setToNonResourceURLs(Integer index,String item);
  public A addToNonResourceURLs(java.lang.String... items);
  public A addAllToNonResourceURLs(Collection<String> items);
  public A removeFromNonResourceURLs(java.lang.String... items);
  public A removeAllFromNonResourceURLs(Collection<String> items);
  public List<String> getNonResourceURLs();
  public String getNonResourceURL(Integer index);
  public String getFirstNonResourceURL();
  public String getLastNonResourceURL();
  public String getMatchingNonResourceURL(Predicate<String> predicate);
  public Boolean hasMatchingNonResourceURL(Predicate<String> predicate);
  public A withNonResourceURLs(List<String> nonResourceURLs);
  public A withNonResourceURLs(java.lang.String... nonResourceURLs);
  public Boolean hasNonResourceURLs();
  public A addToVerbs(Integer index,String item);
  public A setToVerbs(Integer index,String item);
  public A addToVerbs(java.lang.String... items);
  public A addAllToVerbs(Collection<String> items);
  public A removeFromVerbs(java.lang.String... items);
  public A removeAllFromVerbs(Collection<String> items);
  public List<String> getVerbs();
  public String getVerb(Integer index);
  public String getFirstVerb();
  public String getLastVerb();
  public String getMatchingVerb(Predicate<String> predicate);
  public Boolean hasMatchingVerb(Predicate<String> predicate);
  public A withVerbs(List<String> verbs);
  public A withVerbs(java.lang.String... verbs);
  public Boolean hasVerbs();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}

==> kubernetes-model-admissionregistration-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/authorization/v1/NonResourceRuleFluent.java <==
package io.fabric8.kubernetes.api.model.authorization.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface NonResourceRuleFluent<A extends NonResourceRuleFluent<A>> extends Fluent<A>{
  public A addToNonResourceURLs(int index,String item);
  public A setToNonResourceURLs(int index,String item);
  public A addToNonResourceURLs(java.lang.String... items);
  public A addAllToNonResourceURLs(Collection<String> items);
  public A removeFromNonResourceURLs(java.lang.String... items);
  public A removeAllFromNonResourceURLs(Collection<String> items);
  public List<String> getNonResourceURLs();
  public String getNonResourceURL(int index);
  public String getFirstNonResourceURL();
  public String getLastNonResourceURL();
  public String getMatchingNonResourceURL(Predicate<String> predicate);
  public Boolean hasMatchingNonResourceURL(Predicate<String> predicate);
  public A withNonResourceURLs(List<String> nonResourceURLs);
  public A withNonResourceURLs(java.lang.String... nonResourceURLs);
  public Boolean hasNonResourceURLs();
  public A addToVerbs(int index,String item);
  public A setToVerbs(int index,String item);
  public A addToVerbs(java.lang.String... items);
  public A addAllToVerbs(Collection<String> items);
  public A removeFromVerbs(java.lang.String... items);
  public A removeAllFromVerbs(Collection<String> items);
  public List<String> getVerbs();
  public String getVerb(int index);
  public String getFirstVerb();
  public String getLastVerb();
  public String getMatchingVerb(Predicate<String> predicate);
  public Boolean hasMatchingVerb(Predicate<String> predicate);
  public A withVerbs(List<String> verbs);
  public A withVerbs(java.lang.String... verbs);
  public Boolean hasVerbs();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}
